richardview.majumdar\_lab\_widgets.picarro\_crd\_widget module
==============================================================

.. automodule:: richardview.majumdar_lab_widgets.picarro_crd_widget
   :members:
   :undoc-members:
   :show-inheritance:
